diff --git a/doc/src/sgml/config.sgml b/doc/src/sgml/config.sgml
new file mode 100644
index 23ebc11..5a1d9ac
*** a/doc/src/sgml/config.sgml
--- b/doc/src/sgml/config.sgml
*************** dynamic_library_path = 'C:\tools\postgre
*** 6169,6174 ****
--- 6169,6188 ----
        </listitem>
       </varlistentry>
  
+      <varlistentry id="guc-data-checksums" xreflabel="data_checksums">
+       <term><varname>data_checksums</varname> (<type>boolean</type>)</term>
+       <indexterm>
+        <primary><varname>data_checksums</> configuration parameter</primary>
+       </indexterm>
+       <listitem>
+        <para>
+         Reports wether data checksums are turned on or off for this
+         particular cluster. See <xref linkend="app-initdb-data-checksums"> for more
+         information.
+        </para>
+       </listitem>
+      </varlistentry>
+ 
       <varlistentry id="guc-integer-datetimes" xreflabel="integer_datetimes">
        <term><varname>integer_datetimes</varname> (<type>boolean</type>)</term>
        <indexterm>
diff --git a/src/backend/utils/misc/guc.c b/src/backend/utils/misc/guc.c
new file mode 100644
index 7d297bc..f2fccc4
*** a/src/backend/utils/misc/guc.c
--- b/src/backend/utils/misc/guc.c
*************** static bool check_application_name(char 
*** 199,204 ****
--- 199,205 ----
  static void assign_application_name(const char *newval, void *extra);
  static const char *show_unix_socket_permissions(void);
  static const char *show_log_file_mode(void);
+ static const char *show_data_checksums(void);
  
  static char *config_enum_get_options(struct config_enum * record,
  						const char *prefix, const char *suffix,
*************** static int	max_identifier_length;
*** 466,471 ****
--- 467,473 ----
  static int	block_size;
  static int	segment_size;
  static int	wal_block_size;
+ static bool data_checksums;
  static int	wal_segment_size;
  static bool integer_datetimes;
  static int	effective_io_concurrency;
*************** static struct config_bool ConfigureNames
*** 1457,1462 ****
--- 1459,1476 ----
  		NULL, NULL, NULL
  	},
  
+ 	{
+ 		{"data_checksums", PGC_INTERNAL, PRESET_OPTIONS,
+ 		 gettext_noop("Shows wether data checksums are turned on for this cluster"),
+ 		 NULL,
+ 		 GUC_NOT_IN_SAMPLE | GUC_DISALLOW_IN_FILE
+ 		},
+ 		&data_checksums,
+ 		false,
+ 		NULL, NULL, show_data_checksums
+ 	},
+ 
+ 
  	/* End-of-list marker */
  	{
  		{NULL, 0, 0, NULL, NULL}, NULL, false, NULL, NULL, NULL
*************** assign_tcp_keepalives_idle(int newval, v
*** 8656,8661 ****
--- 8670,8684 ----
  }
  
  static const char *
+ show_data_checksums(void)
+ {
+ 	if (DataChecksumsEnabled())
+ 		return "on";
+ 	else
+ 		return "off";
+ }
+ 
+ static const char *
  show_tcp_keepalives_idle(void)
  {
  	/* See comments in assign_tcp_keepalives_idle */
